@@ -138,7 +138,7 @@ class BrailleGenerator(generator.Generator):
 
         # egg-list-box, e.g. privacy panel in gnome-control-center
         if obj.parent and obj.parent.getRole() == pyatspi.ROLE_LIST_BOX:
-            doNotPresent.append(pyatspi.ROLE_FILLER)
+            doNotPresent.append(obj.getRole())
 
         if verbosityLevel == settings.VERBOSITY_LEVEL_BRIEF:
             doNotPresent.extend([pyatspi.ROLE_ICON, pyatspi.ROLE_CANVAS])
