@@ -36,7 +36,7 @@ cgettext = gettext.gettext
 
 # Tell gettext where to find localized strings.
 #
-localedir = os.path.join ("/home/dev/checkout/gnome/orca/bld", "share", "locale")
+localedir = os.path.join ("/opt/gnome", "share", "locale")
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
@@ -57,16 +57,15 @@ def C_(ctx, s):
 def setModuleLocale(moduleName, newLocale=None):
     global _, ngettext, cgettext
 
-    if not newLocale:
-        _ = gettext.gettext
-        ngettext = gettext.ngettext
-        cgettext = gettext.gettext
-    else:
+    try:
         translation = gettext.translation('orca', localedir, languages=[newLocale])
         _ = translation.gettext
         ngettext = translation.ngettext
         cgettext = translation.gettext
-
+    except:
+        _ = gettext.gettext
+        ngettext = gettext.ngettext
+        cgettext = gettext.gettext
     module = sys.modules.get(moduleName)
     if module:
         imp.reload(module)
@@ -84,8 +83,8 @@ def setLocaleForNames(newLocale=None):
         setModuleLocale(module, newLocale)
 
 def setLocaleForGUI(newLocale=None):
-    modules = ['orca.orca_gtkbuilder', 'orca.orca_gui_prefs',
-               'orca.app_gui_prefs', 'orca.guilabels',
+    modules = ['orca.orca_gtkbuilder',
+               'orca.guilabels',
                'orca.brltablenames']
     for module in modules:
         setModuleLocale(module, newLocale)
